Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(313)

Unified Diff: ppapi/c/private/ppp_content_decryptor_private.h

Issue 11270057: Add type argument to pepper content decryptor method GenerateKeyRequest(). (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ppapi/c/private/ppp_content_decryptor_private.h
diff --git a/ppapi/c/private/ppp_content_decryptor_private.h b/ppapi/c/private/ppp_content_decryptor_private.h
index 599e2749d7e6e16f8a54de26c64ad5b0d92db467..797537030d1c6ad57852375117ee24df52495a4b 100644
--- a/ppapi/c/private/ppp_content_decryptor_private.h
+++ b/ppapi/c/private/ppp_content_decryptor_private.h
@@ -4,7 +4,7 @@
*/
/* From private/ppp_content_decryptor_private.idl,
- * modified Mon Oct 22 19:47:57 2012.
+ * modified Thu Oct 25 21:09:46 2012.
*/
#ifndef PPAPI_C_PRIVATE_PPP_CONTENT_DECRYPTOR_PRIVATE_H_
@@ -45,8 +45,8 @@
struct PPP_ContentDecryptor_Private_0_5 {
/**
* Generates a key request. key_system specifies the key or licensing system
* to use. init_data is a data buffer containing data for use in generating
* the request.
*
* Note: <code>GenerateKeyRequest()</code> must create the session ID used in
* other methods on this interface. The session ID must be provided to the
@@ -56,12 +56,16 @@ struct PPP_ContentDecryptor_Private_0_5 {
* @param[in] key_system A <code>PP_Var</code> of type
* <code>PP_VARTYPE_STRING</code> containing the name of the key system.
*
+ * @param[in] mime_type A <code>PP_Var</code> of type
+ * <code>PP_VARTYPE_STRING</code> containing the MIME type for init_data.
+ *
* @param[in] init_data A <code>PP_Var</code> of type
* <code>PP_VARTYPE_ARRAYBUFFER</code> containing container specific
* initialization data.
*/
void (*GenerateKeyRequest)(PP_Instance instance,
struct PP_Var key_system,
+ struct PP_Var mime_type,
struct PP_Var init_data);
/**
* Provides a key or license to the decryptor for decrypting media data.
@@ -45,8 +45,8 @@
/**
* Generates a key request. key_system specifies the key or licensing system
- * to use. init_data is a data buffer containing data for use in generating
- * the request.
+ * to use. mime_type contains the MIME type of init_data. init_data is a data
+ * buffer containing data for use in generating the request.
*
* Note: <code>GenerateKeyRequest()</code> must create the session ID used in

Powered by Google App Engine
This is Rietveld 408576698